==> pwsafe-2.16-src.zip: pwsafe-2.16-src/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by PasswordSafe.rc
//
#define ID_BROWSE                       3
#define ID_CREATE_DB                    4
#define ID_EXIT                         5
#define IDD_ABOUTBOX                    100
#define IDD_FIND                        101
#define IDD_PASSWORDSAFE_DIALOG         102
#define IDS_OUTPUTFILE                  102
#define ID_SYSMENU_ALWAYSONTOP          102
#define IDS_STATEDIT                    103
#define IDS_STATBROWSE                  104
#define IDS_STATCOMPANY                 105
#define IDS_STATCOPY                    106
#define IDS_ALWAYSONTOP                 107
#define IDR_MAINFRAME                   128
#define IDR_ACCS                        128
#define IDD_KEYCHANGE_DIALOG            131
#define IDD_PASSKEYSETUP                132
#define IDD_SECURECLEAR                 133
#define IDD_PASSKEYENTRY_FIRST          135
#define IDD_CONFIRMDELETE_DIALOG        136
#define IDD_OPTIONS                     137
#define IDD_EDIT                        139
#define IDD_MINIMIZECLEAR_DIALOG        141
#define IDD_ADD                         142
#define IDD_TRYAGAIN                    143
#define IDD_REMIND_SAVE                 144
#define IDB_PSLOGO                      148
#define IDB_CLOGO                       150
#define IDB_CTEXT                       151
#define IDD_CRYPTKEYENTRY               160
#define IDR_MAINMENU                    162
#define IDR_POPMENU                     166
#define IDD_QUERYSETDEF                 167
#define IDR_POPGROUP                    168
#define IDR_POPTREE                     169
#define IDD_QUERYADDNAME                183
#define IDD_USERNAMEENTRY               184
#define IDD_PASSKEYENTRY                185
#define IDR_MAINBAR                     187
#define IDD_PASSKEYENTRY_WITHEXIT       188
#define IDB_CLOGO_SMALL                 189
#define IDI_CORNERICON                  191
#define IDD_PS_SECURITY                 194
#define IDD_PS_DISPLAY                  195
#define IDD_PS_USERNAME                 196
#define IDD_PS_PASSWORDPOLICY           197
#define IDD_PS_MISC                     198
#define IDB_NODE                        199
#define IDB_LEAF                        200
#define IDD_EXPORT_TEXT                 204
#define IDR_TOOLBAR1                    208
#define IDB_TOOLBAR1                    208
#define IDB_TOOLBAR2                    217
#define IDR_POPTRAY                     218
#define IDI_TRAY                        219
#define IDI_MBSTOPICON                  221
#define IDI_MBASKICON                   222
#define IDI_MBWARNICON                  223
#define IDI_MBINFOICON                  224
#define IDD_IMPORT_TEXT                 225
#define IDB_TOOLBAR1_RO                 908
#define IDB_TOOLBAR2_RO                 917
#define IDR_MAINBAR_RO                  987
#define IDC_PASSWORD                    1000
#define IDC_ITEMLIST                    1000
#define IDC_OLDPASSKEY                  1001
#define IDC_NEWPASSKEY                  1002
#define IDC_CONFIRMNEW                  1003
#define IDC_TITLE                       1004
#define IDC_USERNAME                    1005
#define IDC_NOTES                       1006
#define IDC_SHOWPASSWORD                1008
#define IDC_CLEARCHECK                  1009
#define IDC_PASSKEY                     1010
#define IDC_DELITEM                     1010
#define IDC_VERIFY                      1012
#define IDC_CONFIRMDELETE               1014
#define IDC_CLEARBOARD                  1015
#define IDC_CONFIRMCOPY                 1016
#define IDC_TRYAGAIN                    1024
#define IDC_QUIT                        1025
#define IDC_OPEN                        1027
#define IDC_RANDOM                      1028
#define IDC_LOCKBASE                    1029
#define IDC_SAVEMINIMIZE                1030
#define IDC_DEFPWSHOW                   1031
#define IDC_DEFPWSHOWINEDIT             1031
#define IDC_USEDEFUSER                  1032
#define IDC_QUERYSETDEF                 1033
#define IDC_QUERYADDNAME                1034
#define IDC_DEFPWSHOWINLIST             1035
#define IDC_CRYPTKEY1                   1045
#define IDC_CRYPTKEY2                   1046
#define IDC_DEFUSERNAME                 1049
#define IDC_STATIC_USERNAME             1050
#define IDC_DEFPWLENGTH                 1051
#define IDC_MESSAGE                     1052
#define IDC_STATIC_DEFPWLENGTH          1052
#define IDC_QUERYCHECK                  1053
#define IDC_STATIC_RULES                1053
#define IDC_STATIC_MINLOWERCASE         1054
#define IDC_MAKEDEF                     1055
#define IDC_STATIC_MINUPPERCASE         1055
#define IDC_NEW                         1056
#define IDC_STATIC_MINDIGITS            1056
#define IDC_STATIC_ICON1                1057
#define IDC_STATIC_MINSYMBOLS           1057
#define IDC_MINLOWERCASE                1058
#define IDC_MINUPPERCASE                1059
#define IDC_STATIC_ICON2                1060
#define IDC_STATIC_LOGO                 1060
#define IDC_MINDIGITS                   1060
#define IDC_STATIC_ICON3                1061
#define IDC_MINSYMBOLS                  1061
#define IDC_FIND_TEXT                   1062
#define IDC_FIND_CS                     1063
#define IDC_STATUS                      1064
#define IDC_ALWAYSONTOP                 1065
#define IDC_STATIC_LOGOTEXT             1066
#define IDC_SAVEIMMEDIATELY             1066
#define IDC_SPIN1                       1068
#define IDC_USELOWERCASE                1069
#define IDC_USEUPPERCASE                1070
#define IDC_USEDIGITS                   1071
#define IDC_USESYMBOLS                  1072
#define IDC_SPINLOWERCASE               1073
#define IDC_SPINUPPERCASE               1074
#define IDC_SPINDIGITS                  1075
#define IDC_SPINSYMBOLS                 1076
#define IDC_EASYVISION                  1077
#define IDC_ITEMTREE                    1078
#define IDC_GROUP                       1079
#define IDC_EXPORT_TEXT_PASSWORD        1081
#define IDC_USEHEXDIGITS                1082
#define IDC_OVERRIDE_POLICY             1082
#define IDC_DEFPWUSESYSTRAY             1083
#define IDC_LOCKONSCREEN                1084
#define IDC_SPIN2                       1085
#define IDC_IDLE_TIMEOUT                1086
#define IDC_LOCK_TIMER                  1087
#define IDC_ESC_EXITS                   1088
#define IDC_TAB                         1091
#define IDC_COMMA                       1092
#define IDC_OTHER                       1093
#define IDC_OTHER_SEPARATOR             1094
#define IDC_NO_GROUP                    1096
#define IDC_YES_GROUP                   1097
#define IDC_GROUP_NAME                  1098
#define IDC_READONLY                    1100
#define IDC_HOTKEY_CTRL                 1102
#define IDC_HOTKEY_ENABLE               1103
#define IDC_QUERYSETIMPDELIM            1104
#define IDC_DEFIMPDELIM                 1105
#define IDC_QUERYSETEXPDELIM            1106
#define IDC_DEFEXPDELIM                 1107
#define IDC_STATIC_MAXMRUITEMS          1108
#define IDC_MAXMRUITEMS                 1109
#define IDC_STATIC_GBMRU                1110
#define IDC_MRU_ONFILEMENU              1111
#define IDC_STATIC_RESTART              1112
#define IDC_DOUBLE_CLICK_COPIES         2089
#define IDC_DOUBLE_CLICK_EDITS          2090
#define IDC_DOUBLE_CLICK_AUTOTYPES      2091
#define IDC_DOUBLE_CLICK_BROWSE         2092
#define IDC_DOUBLE_CLICK_AUTOTYPES2     2092
#define ID_MENUITEM_SAVE                32771
#define ID_MENUITEM_EXIT                32772
#define ID_MENUITEM_ADD                 32773
#define ID_MENUITEM_EDIT                32774
#define ID_MENUITEM_DELETE              32775
#define ID_MENUITEM_COPYPASSWORD        32776
#define ID_MENUITEM_CLEARCLIPBOARD      32777
#define ID_MENUITEM_CHANGECOMBO         32778
#define ID_MENUITEM_BACKUPSAFE          32779
#define ID_MENUITEM_BACKUP              32779
#define ID_MENUITEM_OPTIONS             32780
#define ID_MENUITEM_ABOUT               32782
#define ID_MENUITEM_COPYUSERNAME        32787
#define ID_MENUITEM_OPEN                32793
#define ID_MENUITEM_NEW                 32794
#define ID_MENUTIME_SAVEAS              32795
#define ID_MENUITEM_RESTORE             32797
#define ID_MENUITEM_UPDATEBACKUPS       32798
#define ID_TOOLBUTTON_SAVE              32799
#define ID_TOOLBUTTON_COPYPASSWORD      32802
#define ID_TOOLBUTTON_EDIT              32803
#define ID_TOOLBUTTON_DELETE            32804
#define ID_TOOLBUTTON_ADD               32805
#define ID_TOOLBUTTON_HELP              32806
#define ID_TOOLBUTTON_COPYUSERNAME      32807
#define ID_TOOLBUTTON_NEW               32809
#define ID_TOOLBUTTON_OPEN              32810
#define ID_MENUITEM_FIND                32812
#define ID_TOOLBUTTON_CLEARCLIPBOARD    32813
#define ID_FILE_EXPORTTO_OLD1XFORMAT    32824
#define ID_FILE_EXPORTTO_PLAINTEXT      32825
#define ID_MENUITEM_LIST_VIEW           32826
#define ID_MENUITEM_TREE_VIEW           32827
#define ID_MENUITEM_ADDGROUP            32829
#define ID_MENUITEM_BROWSE              32830
#define ID_MENUITEM_NEW_TOOLBAR         32831
#define ID_MENUITEM_OLD_TOOLBAR         32832
#define ID_MENUITEM_MINIMIZE            32833
#define ID_MENUITEM_UNMINIMIZE          32834
#define ID_MENUITEM_AUTOTYPE            32835
#define ID_PWSAFE_WEBSITE               32836
#define ID_MENUITEM_RENAME              32838
#define ID_FILE_EXPORTTO_XML            32839
#define ID_FILE_IMPORT_XML              32840
#define ID_FILE_IMPORT_PLAINTEXT        32841
#define ID_MENUITEM_MERGE               32842
#define ID_FILE_IMPORT_KEEPASS          32843
#define ID_MENUITEM_DUPLICATEENTRY      32844
#define ID_MENUITEM_EXPANDALL           32845
#define ID_MENUITEM_COLLAPSEALL         32846
#define ID_MENUITEM_CHANGEFONT          32847
#define ID_FILE_MRU_ENTRY1              40001
#define ID_FILE_MRU_ENTRY20             40020
#define IDS_STATAUTOTYPE                57671

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        226
#define _APS_NEXT_COMMAND_VALUE         32848
#define _APS_NEXT_CONTROL_VALUE         1114
#define _APS_NEXT_SYMED_VALUE           105
#endif
#endif

==> pwsafe-3.01-src.zip: pwsafe-3.01-src/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by PasswordSafe.rc
//
#define ID_BROWSE                       3
#define ID_CREATE_DB                    4
#define ID_EXIT                         5
#define IDD_ABOUTBOX                    100
#define IDD_FIND                        101
#define IDD_PASSWORDSAFE_DIALOG         102
#define IDS_OUTPUTFILE                  102
#define ID_SYSMENU_ALWAYSONTOP          102
#define IDS_STATEDIT                    103
#define IDS_STATBROWSE                  104
#define IDS_STATCOMPANY                 105
#define IDS_STATCOPY                    106
#define IDS_ALWAYSONTOP                 107
#define IDR_MAINFRAME                   128
#define IDR_ACCS                        128
#define IDD_KEYCHANGE_DIALOG            131
#define IDD_PASSKEYSETUP                132
#define IDD_SECURECLEAR                 133
#define IDD_PASSKEYENTRY_FIRST          135
#define IDD_CONFIRMDELETE_DIALOG        136
#define IDD_OPTIONS                     137
#define IDD_EDIT                        139
#define IDD_MINIMIZECLEAR_DIALOG        141
#define IDD_ADD                         142
#define IDD_TRYAGAIN                    143
#define IDD_REMIND_SAVE                 144
#define IDB_PSLOGO                      148
#define IDB_CLOGO                       150
#define IDB_CTEXT                       151
#define IDD_CRYPTKEYENTRY               160
#define IDR_MAINMENU                    162
#define IDR_POPMENU                     166
#define IDD_QUERYSETDEF                 167
#define IDR_POPGROUP                    168
#define IDR_POPTREE                     169
#define IDD_QUERYADDNAME                183
#define IDD_USERNAMEENTRY               184
#define IDD_PASSKEYENTRY                185
#define IDD_PASSKEYENTRY_WITHEXIT       188
#define IDB_CLOGO_SMALL                 189
#define IDI_CORNERICON                  191
#define IDI_LOCKEDICON                  192
#define IDI_UNLOCKEDICON                193
#define IDD_PS_SECURITY                 194
#define IDD_PS_DISPLAY                  195
#define IDD_PS_USERNAME                 196
#define IDD_PS_PASSWORDPOLICY           197
#define IDD_PS_MISC                     198
#define IDB_NODE                        199
#define IDB_LEAF                        200
#define IDB_LEAF_EXPIRED                201
#define IDD_EXPORT_TEXT                 204
#define IDB_TOOLBAR1                    212
#define IDB_TOOLBAR2                    213
#define IDB_TOOLBAR3                    214
#define IDR_POPTRAY                     218
#define IDI_TRAY                        219
#define IDI_MBSTOPICON                  221
#define IDI_MBASKICON                   222
#define IDI_MBWARNICON                  223
#define IDI_MBINFOICON                  224
#define IDD_IMPORT_TEXT                 225
#define IDD_PICKEXPDATETIME             226
#define IDD_DISPLAY_EXPIRED_ENTRIES     227
#define IDC_PASSWORD                    1000
#define IDC_ITEMLIST                    1000
#define IDC_OLDPASSKEY                  1001
#define IDC_NEWPASSKEY                  1002
#define IDC_CONFIRMNEW                  1003
#define IDC_TITLE                       1004
#define IDC_USERNAME                    1005
#define IDC_NOTES                       1006
#define IDC_SHOWPASSWORD                1008
#define IDC_CLEARCHECK                  1009
#define IDC_PASSKEY                     1010
#define IDC_DELITEM                     1010
#define IDC_VERIFY                      1012
#define IDC_CONFIRMDELETE               1014
#define IDC_CLEARBOARD                  1015
#define IDC_CONFIRMCOPY                 1016
#define IDC_TRYAGAIN                    1024
#define IDC_QUIT                        1025
#define IDC_OPEN                        1027
#define IDC_RANDOM                      1028
#define IDC_LOCKBASE                    1029
#define IDC_SAVEMINIMIZE                1030
#define IDC_DEFPWSHOW                   1031
#define IDC_DEFPWSHOWINEDIT             1031
#define IDC_USEDEFUSER                  1032
#define IDC_QUERYSETDEF                 1033
#define IDC_QUERYADDNAME                1034
#define IDC_DEFPWSHOWINLIST             1035
#define IDC_CRYPTKEY1                   1045
#define IDC_CRYPTKEY2                   1046
#define IDC_DEFUSERNAME                 1049
#define IDC_STATIC_USERNAME             1050
#define IDC_DEFPWLENGTH                 1051
#define IDC_MESSAGE                     1052
#define IDC_STATIC_DEFPWLENGTH          1052
#define IDC_QUERYCHECK                  1053
#define IDC_STATIC_RULES                1053
#define IDC_STATIC_MINLOWERCASE         1054
#define IDC_MAKEDEF                     1055
#define IDC_STATIC_MINUPPERCASE         1055
#define IDC_NEW                         1056
#define IDC_STATIC_MINDIGITS            1056
#define IDC_STATIC_ICON1                1057
#define IDC_STATIC_MINSYMBOLS           1057
#define IDC_MINLOWERCASE                1058
#define IDC_MINUPPERCASE                1059
#define IDC_STATIC_ICON2                1060
#define IDC_STATIC_LOGO                 1060
#define IDC_MINDIGITS                   1060
#define IDC_STATIC_ICON3                1061
#define IDC_MINSYMBOLS                  1061
#define IDC_FIND_TEXT                   1062
#define IDC_FIND_CS                     1063
#define IDC_STATUS                      1064
#define IDC_ALWAYSONTOP                 1065
#define IDC_STATIC_LOGOTEXT             1066
#define IDC_SAVEIMMEDIATELY             1066
#define IDC_SPIN1                       1068
#define IDC_USELOWERCASE                1069
#define IDC_USEUPPERCASE                1070
#define IDC_USEDIGITS                   1071
#define IDC_USESYMBOLS                  1072
#define IDC_SPINLOWERCASE               1073
#define IDC_SPINUPPERCASE               1074
#define IDC_SPINDIGITS                  1075
#define IDC_SPINSYMBOLS                 1076
#define IDC_EASYVISION                  1077
#define IDC_ITEMTREE                    1078
#define IDC_GROUP                       1079
#define IDC_EXPORT_TEXT_PASSWORD        1081
#define IDC_USEHEXDIGITS                1082
#define IDC_OVERRIDE_POLICY             1082
#define IDC_DEFPWUSESYSTRAY             1083
#define IDC_LOCKONSCREEN                1084
#define IDC_DEFPWRECENTRYHELP           1084
#define IDC_SPIN2                       1085
#define IDC_IDLE_TIMEOUT                1086
#define IDC_LOCK_TIMER                  1087
#define IDC_ESC_EXITS                   1088
#define IDC_TAB                         1091
#define IDC_COMMA                       1092
#define IDC_OTHER                       1093
#define IDC_OTHER_SEPARATOR             1094
#define IDC_NO_GROUP                    1096
#define IDC_YES_GROUP                   1097
#define IDC_GROUP_NAME                  1098
#define IDC_READONLY                    1100
#define IDC_HOTKEY_CTRL                 1102
#define IDC_HOTKEY_ENABLE               1103
#define IDC_QUERYSETIMPDELIM            1104
#define IDC_DEFIMPDELIM                 1105
#define IDC_QUERYSETEXPDELIM            1106
#define IDC_DEFEXPDELIM                 1107
#define IDC_STATIC_MAXMRUITEMS          1108
#define IDC_MAXMRUITEMS                 1109
#define IDC_STATIC_GBMRU                1110
#define IDC_MRU_ONFILEMENU              1111
#define IDC_STATIC_RESTART              1112
#define IDC_STATIC_MAXREITEMS           1113
#define IDC_MAXREITEMS                  1114
#define IDC_MORE                        1115
#define IDC_URL                         1116
#define IDC_AUTOTYPE                    1117
#define IDC_EXPIRYDATE                  1118
#define IDC_EXPIRYTIME                  1119
#define IDC_STATIC_CURRENT_LTIME        1120
#define IDC_STATIC_URL                  1124
#define IDC_STATIC_AUTO                 1125
#define IDC_STATIC_CTIME                1128
#define IDC_CTIME                       1129
#define IDC_STATIC_PMTIME               1130
#define IDC_PMTIME                      1131
#define IDC_STATIC_ATIME                1132
#define IDC_ATIME                       1133
#define IDC_STATIC_LTIME                1134
#define IDC_LTIME                       1135
#define IDC_STATIC_RMTIME               1136
#define IDC_RMTIME                      1137
#define IDC_LTIME_CLEAR                 1138
#define IDC_LTIME_SET                   1139
#define IDC_LTIME_PICKER                1140
#define IDC_MAINTAINDATETIMESTAMPS      1141
#define IDC_STATIC_DTGROUP              1142
#define IDC_STATIC_DTEXP_GROUP          1143
#define IDC_STATIC_DTEXPGROUP           1144
#define IDC_TOP_HIDEABLE                1145
#define IDC_BOTTOM_HIDEABLE             1146
#define IDC_EXPIRED_PASSWORD_LIST       1147
#define IDC_COPY_EXP_TO_CLIPBOARD       1148
#define IDC_IMPORT_PREV3                1149
#define IDC_EXPORT_HDR                  1150
#define IDC_RESPIN                      1151
#define IDC_MRUSPIN                     1152
#define IDC_DOUBLE_CLICK_COPIES         2089
#define IDC_DOUBLE_CLICK_EDITS          2090
#define IDC_DOUBLE_CLICK_AUTOTYPES      2091
#define IDC_DOUBLE_CLICK_BROWSE         2092
#define ID_MENUITEM_SAVE                32771
#define ID_MENUITEM_EXIT                32772
#define ID_MENUITEM_ADD                 32773
#define ID_MENUITEM_EDIT                32774
#define ID_MENUITEM_DELETE              32775
#define ID_MENUITEM_COPYPASSWORD        32776
#define ID_MENUITEM_CLEARCLIPBOARD      32777
#define ID_MENUITEM_CHANGECOMBO         32778
#define ID_MENUITEM_BACKUPSAFE          32779
#define ID_MENUITEM_BACKUP              32779
#define ID_MENUITEM_OPTIONS             32780
#define ID_MENUITEM_ABOUT               32782
#define ID_MENUITEM_COPYUSERNAME        32787
#define ID_MENUITEM_COPYNOTESFLD        32788
#define ID_MENUITEM_OPEN                32793
#define ID_MENUITEM_NEW                 32794
#define ID_MENUTIME_SAVEAS              32795
#define ID_MENUITEM_RESTORE             32797
#define ID_MENUITEM_UPDATEBACKUPS       32798
#define ID_TOOLBUTTON_NEW               32800
#define ID_TOOLBUTTON_OPEN              32801
#define ID_TOOLBUTTON_SAVE              32802
#define ID_TOOLBUTTON_COPYUSERNAME      32803
#define ID_TOOLBUTTON_COPYPASSWORD      32804
#define ID_TOOLBUTTON_COPYNOTESFLD      32805
#define ID_TOOLBUTTON_CLEARCLIPBOARD    32806
#define ID_TOOLBUTTON_AUTOTYPE          32807
#define ID_TOOLBUTTON_BROWSEURL         32808
#define ID_TOOLBUTTON_ADD               32809
#define ID_TOOLBUTTON_EDIT              32810
#define ID_TOOLBUTTON_DELETE            32811
#define ID_TOOLBUTTON_HELP              32812
#define ID_MENUITEM_FIND                32824
#define ID_FILE_EXPORTTO_PLAINTEXT      32825
#define ID_MENUITEM_LIST_VIEW           32826
#define ID_MENUITEM_TREE_VIEW           32827
#define ID_MENUITEM_ADDGROUP            32829
#define ID_MENUITEM_BROWSE              32830
#define ID_MENUITEM_NEW_TOOLBAR         32831
#define ID_MENUITEM_OLD_TOOLBAR         32832
#define ID_MENUITEM_MINIMIZE            32833
#define ID_MENUITEM_UNMINIMIZE          32834
#define ID_MENUITEM_AUTOTYPE            32835
#define ID_PWSAFE_WEBSITE               32836
#define ID_FILE_EXPORTTO_OLD1XFORMAT    32837
#define ID_FILE_EXPORTTO_V2FORMAT       32838
#define ID_FILE_EXPORTTO_XML            32839
#define ID_FILE_IMPORT_XML              32840
#define ID_FILE_IMPORT_PLAINTEXT        32841
#define ID_MENUITEM_MERGE               32842
#define ID_FILE_IMPORT_KEEPASS          32843
#define ID_MENUITEM_DUPLICATEENTRY      32844
#define ID_MENUITEM_EXPANDALL           32845
#define ID_MENUITEM_COLLAPSEALL         32846
#define ID_MENUITEM_CHANGEFONT          32847
#define ID_MENUITEM_TRAYLOCKUNLOCK      32848
#define ID_TRAYRECENT_ENTRY_CLEAR       32849
#define ID_MENUITEM_TRAYCOPYUSERNAME    32850
#define ID_MENUITEM_TRAYCOPYPASSWORD    32851
#define ID_MENUITEM_TRAYBROWSE          32852
#define ID_MENUITEM_TRAYDELETE          32853
#define ID_MENUITEM_TRAYAUTOTYPE        32854
#define ID_TRAYRECENT_ENTRY_HELP1       32855
#define ID_TRAYRECENT_ENTRY_HELP2       32856
#define ID_MENUITEM_RENAME              32857
#define ID_MENUITEM_CLEAR_MRU           32858
#define ID_FILE_MRU_ENTRY1              40001
#define ID_FILE_MRU_ENTRYMAX            40020
#define ID_TRAYRECENT_ENTRY1            41001
#define ID_TRAYRECENT_ENTRYMAX          41025
#define ID_MENUITEM_TRAYCOPYUSERNAME1   41026
#define ID_MENUITEM_TRAYCOPYUSERNAMEMAX 41050
#define ID_MENUITEM_TRAYCOPYPASSWORD1   41051
#define ID_MENUITEM_TRAYCOPYPASSWORDMAX 41075
#define ID_MENUITEM_TRAYBROWSE1         41076
#define ID_MENUITEM_TRAYBROWSEMAX       41100
#define ID_MENUITEM_TRAYDELETE1         41101
#define ID_MENUITEM_TRAYDELETEMAX       41125
#define ID_MENUITEM_TRAYAUTOTYPE1       41126
#define ID_MENUITEM_TRAYAUTOTYPEMAX     41150
#define ID_MENUITEM_TRAYCOPYNOTESFLD1   41151
#define ID_MENUITEM_TRAYCOPYNOTESFLDMAX 41175
#define IDS_STATAUTOTYPE                57671

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        228
#define _APS_NEXT_COMMAND_VALUE         32859
#define _APS_NEXT_CONTROL_VALUE         1153
#define _APS_NEXT_SYMED_VALUE           105
#endif
#endif
